MethodChannelFlutterIosAirplay class
An implementation of FlutterIosAirplayPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FlutterIosAirplayPlatform
- MethodChannelFlutterIosAirplay
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
Returns the native platform version string.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
playVideoFromAsset(
{required String asset}) → Future< void> -
Plays a bundled app
assetvideo using native UI.override -
playVideoFromUrl(
{required String url}) → Future< void> -
Plays a video from the given network
urlusing native UI.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited